@@ -43,7 +43,6 @@ KNOWN_REGIONS = {
         'elasticbeanstalk': 'elasticbeanstalk.ap-northeast-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.ap-northeast-1.amazonaws.com',
         'elasticmapreduce': 'elasticmapreduce.ap-northeast-1.amazonaws.com',
-        'elastictranscoder': 'elastictranscoder.ap-northeast-1.amazonaws.com',
         'glacier': 'glacier.ap-northeast-1.amazonaws.com',
         'iot': 'iot.ap-northeast-1.amazonaws.com',
         'kinesis': 'kinesis.ap-northeast-1.amazonaws.com',
@@ -78,7 +77,6 @@ KNOWN_REGIONS = {
         'elasticbeanstalk': 'elasticbeanstalk.ap-southeast-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.ap-southeast-1.amazonaws.com',
         'elasticmapreduce': 'elasticmapreduce.ap-southeast-1.amazonaws.com',
-        'elastictranscoder': 'elastictranscoder.ap-southeast-1.amazonaws.com',
         'kinesis': 'kinesis.ap-southeast-1.amazonaws.com',
         'kms': 'kms.ap-southeast-1.amazonaws.com',
         'logs': 'logs.ap-southeast-1.amazonaws.com',
@@ -206,7 +204,6 @@ KNOWN_REGIONS = {
         'elasticbeanstalk': 'elasticbeanstalk.eu-west-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.eu-west-1.amazonaws.com',
         'elasticmapreduce': 'elasticmapreduce.eu-west-1.amazonaws.com',
-        'elastictranscoder': 'elastictranscoder.eu-west-1.amazonaws.com',
         'email': 'email.eu-west-1.amazonaws.com',
         'glacier': 'glacier.eu-west-1.amazonaws.com',
         'iot': 'iot.eu-west-1.amazonaws.com',
@@ -281,7 +278,6 @@ KNOWN_REGIONS = {
         'elasticbeanstalk': 'elasticbeanstalk.us-east-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.us-east-1.amazonaws.com',
         'elasticmapreduce': 'elasticmapreduce.us-east-1.amazonaws.com',
-        'elastictranscoder': 'elastictranscoder.us-east-1.amazonaws.com',
         'email': 'email.us-east-1.amazonaws.com',
         'glacier': 'glacier.us-east-1.amazonaws.com',
         'iam': 'iam.amazonaws.com',
@@ -347,7 +343,6 @@ KNOWN_REGIONS = {
         'elasticbeanstalk': 'elasticbeanstalk.us-west-1.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.us-west-1.amazonaws.com',
         'elasticmapreduce': 'elasticmapreduce.us-west-1.amazonaws.com',
-        'elastictranscoder': 'elastictranscoder.us-west-1.amazonaws.com',
         'glacier': 'glacier.us-west-1.amazonaws.com',
         'kinesis': 'kinesis.us-west-1.amazonaws.com',
         'kms': 'kms.us-west-1.amazonaws.com',
@@ -385,7 +380,6 @@ KNOWN_REGIONS = {
         'elasticfilesystem': 'elasticfilesystem.us-west-2.amazonaws.com',
         'elasticloadbalancing': 'elasticloadbalancing.us-west-2.amazonaws.com',
         'elasticmapreduce': 'elasticmapreduce.us-west-2.amazonaws.com',
-        'elastictranscoder': 'elastictranscoder.us-west-2.amazonaws.com',
         'email': 'email.us-west-2.amazonaws.com',
         'glacier': 'glacier.us-west-2.amazonaws.com',
         'iot': 'iot.us-west-2.amazonaws.com',
